Skip to content
New issue

Have a question about this project? Sign up for a free GitHub account to open an issue and contact its maintainers and the community.

By clicking “Sign up for GitHub”, you agree to our terms of service and privacy statement. We’ll occasionally send you account related emails.

Already on GitHub? Sign in to your account

Allow mousetrap to work in inputs #516

Open
Serraniel opened this issue Jul 2, 2024 · 0 comments
Open

Allow mousetrap to work in inputs #516

Serraniel opened this issue Jul 2, 2024 · 0 comments

Comments

@Serraniel
Copy link

Hi! 👋

Firstly, thanks for your work on this project! 🙂

Today I used patch-package to patch mousetrap@1.6.5 for the project I'm working on.

Here is the diff that solved my problem:

diff --git a/node_modules/mousetrap/mousetrap.js b/node_modules/mousetrap/mousetrap.js
index ab71d58..97c3464 100644
--- a/node_modules/mousetrap/mousetrap.js
+++ b/node_modules/mousetrap/mousetrap.js
@@ -432,9 +432,13 @@
         return _belongsTo(element.parentNode, ancestor);
     }
 
-    function Mousetrap(targetElement) {
+    function Mousetrap(targetElement, options) {
         var self = this;
 
+        // Standardoptionen
+        self.options = options || {};
+        self.options.allowInInputs = self.options.allowInInputs || false;
+
         targetElement = targetElement || document;
 
         if (!(self instanceof Mousetrap)) {
@@ -996,8 +1000,12 @@
             }
         }
 
-        // stop for input, select, and textarea
-        return element.tagName == 'INPUT' || element.tagName == 'SELECT' || element.tagName == 'TEXTAREA' || element.isContentEditable;
+        // Stop for input, select, and textarea if allowInInputs is not set
+        if (!self.options.allowInInputs) {
+            return element.tagName == 'INPUT' || element.tagName == 'SELECT' || element.tagName == 'TEXTAREA' || element.isContentEditable;
+        }
+
+        return false;
     };
 
     /**

This issue body was partially generated by patch-package.

Sign up for free to join this conversation on GitHub. Already have an account? Sign in to comment
Labels
None yet
Projects
None yet
Development

No branches or pull requests

1 participant